## ecr.core.globalData

src/ecr/core/globalData.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    from . import manager, path
    from .. import log

    def exists() -> bool:
        return manager.hasInitialized(path.getGlobalBasePath())

    def initialize() -> None:
        log.info("Initialize global data.")
        manager.clear(path.getGlobalBasePath())
        manager.initialize(path.getGlobalBasePath())